====
PyDL
====

Introduction
++++++++++++

This is the documentation for PyDL.

Components
++++++++++

Most of the functionality of PyDL is in sub-packages.

.. toctree::
   :maxdepth: 1

   goddard.rst
   photoop.rst
   pydlspec2d.rst
   pydlutils.rst

Other Notes
+++++++++++

.. toctree::
   :maxdepth: 1

   changes.rst
   todo.rst
   credits.rst

Base API
++++++++

.. automodapi:: pydl
   :no-inheritance-diagram:
